@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -28,7 +28,7 @@ OF_ASSUME_NONNULL_BEGIN
 extern "C" {
 #endif
 extern OFIRI *_OFArchiveIRIHandlerIRIForFileInArchive(OFString *, OFString *,
-    OFIRI *) OF_VISIBILITY_HIDDEN;
+    OFIRI *) OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
