@@ -26,6 +26,8 @@
 #import "OFArray+Private.h"
 #import "OFConcreteArray.h"
 #import "OFData.h"
+#import "OFIndexSet.h"
+#import "OFIndexSet+Private.h"
 #import "OFJSONRepresentationPrivate.h"
 #import "OFNull.h"
 #import "OFString.h"
@@ -134,12 +136,13 @@ OF_SINGLETON_METHODS
 
 + (instancetype)array
 {
-	return [[[self alloc] init] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] init]);
 }
 
 + (instancetype)arrayWithObject: (id)object
 {
-	return [[[self alloc] initWithObject: object] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithObject: object]);
 }
 
 + (instancetype)arrayWithObjects: (id)firstObject, ...
@@ -148,23 +151,24 @@ OF_SINGLETON_METHODS
 	va_list arguments;
 
 	va_start(arguments, firstObject);
-	ret = [[[self alloc] initWithObject: firstObject
-				  arguments: arguments] autorelease];
+	ret = [[self alloc] initWithObject: firstObject
+				 arguments: arguments];
 	va_end(arguments);
 
-	return ret;
+	return objc_autoreleaseReturnValue(ret);
 }
 
 + (instancetype)arrayWithArray: (OFArray *)array
 {
-	return [[[self alloc] initWithArray: array] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithArray: array]);
 }
 
 + (instancetype)arrayWithObjects: (id const *)objects
 			   count: (size_t)count
 {
-	return [[[self alloc] initWithObjects: objects
-					count: count] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithObjects: objects
+				    count: count]);
 }
 
 - (instancetype)init
@@ -174,7 +178,7 @@ OF_SINGLETON_METHODS
 		@try {
 			[self doesNotRecognizeSelector: _cmd];
 		} @catch (id e) {
-			[self release];
+			objc_release(self);
 			@throw e;
 		}
 
@@ -217,7 +221,7 @@ OF_SINGLETON_METHODS
 	@try {
 		objects = OFAllocMemory(count, sizeof(id));
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -249,7 +253,7 @@ OF_SINGLETON_METHODS
 		[array getObjects: objects
 			  inRange: OFMakeRange(0, count)];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -311,7 +315,7 @@ OF_SINGLETON_METHODS
 
 - (id)copy
 {
-	return [self retain];
+	return objc_retain(self);
 }
 
 - (id)mutableCopy
@@ -425,13 +429,13 @@ OF_SINGLETON_METHODS
 	OFArray *ret;
 	id *buffer;
 
-	if (range.length > SIZE_MAX - range.location ||
-	    range.location + range.length < self.count)
+	if (OFEndOfRange(range) > self.count)
 		@throw [OFOutOfRangeException exception];
 
 	if (![self isKindOfClass: [OFMutableArray class]])
-		return [[[OFSubarray alloc] initWithArray: self
-						    range: range] autorelease];
+		return objc_autoreleaseReturnValue(
+		    [[OFSubarray alloc] initWithArray: self
+						range: range]);
 
 	buffer = OFAllocMemory(range.length, sizeof(*buffer));
 	@try {
@@ -445,6 +449,25 @@ OF_SINGLETON_METHODS
 	return ret;
 }
 
+- (OFArray *)objectsAtIndexes: (OFIndexSet *)indexes
+{
+	OFMutableArray *ret = [OFMutableArray arrayWithCapacity: indexes.count];
+	void *pool = objc_autoreleasePoolPush();
+	const OFRange *ranges = indexes.of_ranges.items;
+	size_t rangesCount = indexes.of_ranges.count;
+
+	for (size_t i = 0; i < rangesCount; i++)
+		for (size_t j = ranges[i].location; j < OFEndOfRange(ranges[i]);
+		    j++)
+			[ret addObject: [self objectAtIndex: j]];
+
+	[ret makeImmutable];
+
+	objc_autoreleasePoolPop(pool);
+
+	return ret;
+}
+
 - (OFString *)componentsJoinedByString: (OFString *)separator
 {
 	return [self componentsJoinedByString: separator
@@ -593,7 +616,7 @@ OF_SINGLETON_METHODS
 		[ret replaceOccurrencesOfString: @"\n" withString: @"\n\t"];
 		[ret appendString: @"\n)"];
 	} @catch (id e) {
-		[ret release];
+		objc_release(ret);
 		@throw e;
 	}
 
@@ -601,7 +624,7 @@ OF_SINGLETON_METHODS
 
 	[ret makeImmutable];
 
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 
 - (OFString *)JSONRepresentation
@@ -740,7 +763,7 @@ OF_SINGLETON_METHODS
 
 - (OFArray *)sortedArray
 {
-	OFMutableArray *new = [[self mutableCopy] autorelease];
+	OFMutableArray *new = objc_autorelease([self mutableCopy]);
 	[new sort];
 	[new makeImmutable];
 	return new;
@@ -749,7 +772,7 @@ OF_SINGLETON_METHODS
 - (OFArray *)sortedArrayUsingSelector: (SEL)selector
 			      options: (OFArraySortOptions)options
 {
-	OFMutableArray *new = [[self mutableCopy] autorelease];
+	OFMutableArray *new = objc_autorelease([self mutableCopy]);
 	[new sortUsingSelector: selector options: options];
 	[new makeImmutable];
 	return new;
@@ -759,7 +782,7 @@ OF_SINGLETON_METHODS
 			      context: (void *)context
 			      options: (OFArraySortOptions)options
 {
-	OFMutableArray *new = [[self mutableCopy] autorelease];
+	OFMutableArray *new = objc_autorelease([self mutableCopy]);
 	[new sortUsingFunction: compare context: context options: options];
 	[new makeImmutable];
 	return new;
@@ -769,7 +792,7 @@ OF_SINGLETON_METHODS
 - (OFArray *)sortedArrayUsingComparator: (OFComparator)comparator
 				options: (OFArraySortOptions)options
 {
-	OFMutableArray *new = [[self mutableCopy] autorelease];
+	OFMutableArray *new = objc_autorelease([self mutableCopy]);
 	[new sortUsingComparator: comparator options: options];
 	[new makeImmutable];
 	return new;
@@ -778,7 +801,7 @@ OF_SINGLETON_METHODS
 
 - (OFArray *)reversedArray
 {
-	OFMutableArray *new = [[self mutableCopy] autorelease];
+	OFMutableArray *new = objc_autorelease([self mutableCopy]);
 	[new reverse];
 	[new makeImmutable];
 	return new;
@@ -791,18 +814,15 @@ OF_SINGLETON_METHODS
 	static unsigned long dummyMutations;
 	OFRange range = OFMakeRange(state->state, count);
 
-	if (range.length > SIZE_MAX - range.location)
-		@throw [OFOutOfRangeException exception];
-
-	if (range.location + range.length > self.count)
+	if (OFEndOfRange(range) > self.count)
 		range.length = self.count - range.location;
 
 	[self getObjects: objects inRange: range];
 
-	if (range.location + range.length > ULONG_MAX)
+	if (OFEndOfRange(range) > ULONG_MAX)
 		@throw [OFOutOfRangeException exception];
 
-	state->state = (unsigned long)(range.location + range.length);
+	state->state = (unsigned long)OFEndOfRange(range);
 	state->itemsPtr = objects;
 	state->mutationsPtr = &dummyMutations;
 
@@ -811,8 +831,9 @@ OF_SINGLETON_METHODS
 
 - (OFEnumerator *)objectEnumerator
 {
-	return [[[OFArrayEnumerator alloc] initWithArray: self
-					    mutationsPtr: NULL] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[OFArrayEnumerator alloc] initWithArray: self
+					mutationsPtr: NULL]);
 }
 
 #ifdef OF_HAVE_BLOCKS
@@ -837,7 +858,7 @@ OF_SINGLETON_METHODS
 	if (object == nil)
 		@throw [OFInvalidArgumentException exception];
 
-	ret = [[self mutableCopy] autorelease];
+	ret = objc_autorelease([self mutableCopy]);
 	[ret addObject: object];
 	[ret makeImmutable];
 
@@ -846,7 +867,7 @@ OF_SINGLETON_METHODS
 
 - (OFArray *)arrayByAddingObjectsFromArray: (OFArray *)array
 {
-	OFMutableArray *ret = [[self mutableCopy] autorelease];
+	OFMutableArray *ret = objc_autorelease([self mutableCopy]);
 	[ret addObjectsFromArray: array];
 	[ret makeImmutable];
 
@@ -905,26 +926,27 @@ OF_SINGLETON_METHODS
 	if (count == 0)
 		return nil;
 	if (count == 1)
-		return [[[self objectAtIndex: 0] retain] autorelease];
+		return objc_autoreleaseReturnValue(
+		    objc_retain([self objectAtIndex: 0]));
 
 	[self enumerateObjectsUsingBlock: ^ (id object, size_t idx,
 	    bool *stop) {
 		id new;
 
 		if (idx == 0) {
-			current = [object retain];
+			current = objc_retain(object);
 			return;
 		}
 
 		@try {
-			new = [block(current, object) retain];
+			new = objc_retain(block(current, object));
 		} @finally {
-			[current release];
+			objc_release(current);
 		}
 		current = new;
 	}];
 
-	return [current autorelease];
+	return objc_autoreleaseReturnValue(current);
 }
 #endif
 @end
@@ -935,7 +957,7 @@ OF_SINGLETON_METHODS
 {
 	self = [super init];
 
-	_array = [array retain];
+	_array = objc_retain(array);
 	_count = [array count];
 	_mutations = (mutationsPtr != NULL ? *mutationsPtr : 0);
 	_mutationsPtr = mutationsPtr;
@@ -945,7 +967,7 @@ OF_SINGLETON_METHODS
 
 - (void)dealloc
 {
-	[_array release];
+	objc_release(_array);
 
 	[super dealloc];
 }
