@@ -30,7 +30,7 @@
 extern "C" {
 #endif
 extern uint16_t _OFCRC16(uint16_t crc, const void *_Nonnull bytes,
-    size_t length) OF_VISIBILITY_HIDDEN;
+    size_t length) OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
