@@ -30,18 +30,6 @@
 #import "OFInvalidArgumentException.h"
 #import "OFEnumerationMutationException.h"
 
-static void *
-retain(void *object)
-{
-	return [(id)object retain];
-}
-
-static void
-release(void *object)
-{
-	[(id)object release];
-}
-
 static unsigned long
 hash(void *object)
 {
@@ -55,8 +43,8 @@ equal(void *object1, void *object2)
 }
 
 static const OFMapTableFunctions keyFunctions = {
-	.retain = retain,
-	.release = release,
+	.retain = (void *(*)(void *))objc_retain,
+	.release = (void (*)(void *))objc_release,
 	.hash = hash,
 	.equal = equal
 };
@@ -78,7 +66,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 			 objectFunctions: objectFunctions
 				capacity: capacity];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -95,7 +83,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 	@try {
 		count = set.count;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -105,7 +93,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 		for (id object in set)
 			[_mapTable setObject: (void *)1 forKey: object];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -122,7 +110,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 	@try {
 		count = array.count;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -132,7 +120,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 		for (id object in array)
 			[_mapTable setObject: (void *)1 forKey: object];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -147,7 +135,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 		for (size_t i = 0; i < count; i++)
 			[_mapTable setObject: (void *)1 forKey: objects[i]];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -177,7 +165,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 		while ((object = va_arg(arguments, id)) != nil)
 			[_mapTable setObject: (void *)1 forKey: object];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -186,7 +174,7 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 
 - (void)dealloc
 {
-	[_mapTable release];
+	objc_release(_mapTable);
 
 	[super dealloc];
 }
@@ -234,18 +222,18 @@ static const OFMapTableFunctions objectFunctions = { NULL };
 		return nil;
 	}
 
-	object = [(id)*objectPtr retain];
+	object = objc_retain((id)*objectPtr);
 
 	objc_autoreleasePoolPop(pool);
 
-	return [object autorelease];
+	return objc_autoreleaseReturnValue(object);
 }
 
 - (OFEnumerator *)objectEnumerator
 {
-	return [[[OFMapTableEnumeratorWrapper alloc]
+	return objc_autoreleaseReturnValue([[OFMapTableEnumeratorWrapper alloc]
 	    initWithEnumerator: [_mapTable keyEnumerator]
-			object: self] autorelease];
+			object: self]);
 }
 
 - (int)countByEnumeratingWithState: (OFFastEnumerationState *)state
