@@ -26,7 +26,7 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int _OFData_CryptographicHashing_reference OF_VISIBILITY_HIDDEN;
+extern int _OFData_CryptographicHashing_reference OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
