@@ -56,12 +56,14 @@ isWhitespaceLine(OFString *line)
 
 + (instancetype)fileWithIRI: (OFIRI *)IRI
 {
-	return [[[self alloc] initWithIRI: IRI] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithIRI: IRI]);
 }
 
 + (instancetype)fileWithIRI: (OFIRI *)IRI encoding: (OFStringEncoding)encoding
 {
-	return [[[self alloc] initWithIRI: IRI encoding: encoding] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithIRI: IRI
+			     encoding: encoding]);
 }
 
 - (instancetype)init
@@ -79,12 +81,13 @@ isWhitespaceLine(OFString *line)
 	self = [super init];
 
 	@try {
-		_sections = [[OFMutableArray alloc] initWithObject:
-		    [[[OFINISection alloc] of_initWithName: @""] autorelease]];
+		OFINISection *section = objc_autorelease(
+		    [[OFINISection alloc] of_initWithName: @""]);
+		_sections = [[OFMutableArray alloc] initWithObject: section];
 
 		[self of_parseIRI: IRI encoding: encoding];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -93,7 +96,7 @@ isWhitespaceLine(OFString *line)
 
 - (void)dealloc
 {
-	[_sections release];
+	objc_release(_sections);
 
 	[super dealloc];
 }
@@ -112,7 +115,8 @@ isWhitespaceLine(OFString *line)
 		if ([section.name isEqual: name])
 			return section;
 
-	section = [[[OFINISection alloc] of_initWithName: name] autorelease];
+	section = objc_autorelease(
+	    [[OFINISection alloc] of_initWithName: name]);
 	[_sections addObject: section];
 
 	objc_autoreleasePoolPop(pool);
@@ -145,7 +149,9 @@ isWhitespaceLine(OFString *line)
 		@throw e;
 	}
 
-	while ((line = [file readLineWithEncoding: encoding]) != nil) {
+	file.encoding = encoding;
+
+	while ((line = [file readLine]) != nil) {
 		if (isWhitespaceLine(line))
 			continue;
 
@@ -160,8 +166,8 @@ isWhitespaceLine(OFString *line)
 			if (sectionName.length == 0)
 				@throw [OFInvalidFormatException exception];
 
-			section = [[[OFINISection alloc]
-			    of_initWithName: sectionName] autorelease];
+			section = objc_autorelease([[OFINISection alloc]
+			    of_initWithName: sectionName]);
 			[_sections addObject: section];
 		} else {
 			if (section == nil)
@@ -185,10 +191,10 @@ isWhitespaceLine(OFString *line)
 	OFStream *file = [OFIRIHandler openItemAtIRI: IRI mode: @"w"];
 	bool first = true;
 
+	file.encoding = encoding;
+
 	for (OFINISection *section in _sections)
-		if ([section of_writeToStream: file
-				     encoding: encoding
-					first: first])
+		if ([section of_writeToStream: file first: first])
 			first = false;
 
 	objc_autoreleasePoolPop(pool);
