@@ -75,7 +75,7 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 		@try {
 			[handlers setObject: handler forKey: scheme];
 		} @finally {
-			[handler release];
+			objc_release(handler);
 		}
 	}
 
@@ -101,6 +101,15 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 	return [[self handlerForIRI: IRI] openItemAtIRI: IRI mode: mode];
 }
 
++ (void)asyncOpenItemAtIRI: (OFIRI *)IRI
+		      mode: (OFString *)mode
+		  delegate: (id <OFIRIHandlerDelegate>)delegate
+{
+	[[self handlerForIRI: IRI] asyncOpenItemAtIRI: IRI
+						 mode: mode
+					     delegate: delegate];
+}
+
 - (instancetype)init
 {
 	OF_INVALID_INIT_METHOD
@@ -113,7 +122,7 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 	@try {
 		_scheme = [scheme copy];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -122,7 +131,7 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 
 - (void)dealloc
 {
-	[_scheme release];
+	objc_release(_scheme);
 
 	[super dealloc];
 }
@@ -132,6 +141,13 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 	OF_UNRECOGNIZED_SELECTOR
 }
 
+- (void)asyncOpenItemAtIRI: (OFIRI *)IRI
+		      mode: (OFString *)mode
+		  delegate: (id <OFIRIHandlerDelegate>)delegate
+{
+	OF_UNRECOGNIZED_SELECTOR
+}
+
 - (OFFileAttributes)attributesOfItemAtIRI: (OFIRI *)IRI
 {
 	OF_UNRECOGNIZED_SELECTOR
@@ -208,7 +224,7 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 {
 	/*
 	 * Only call into -[extendedAttributeDataForName:ofItemAtIRI:] if it
-	 * has been overridden. This is to be backwards-compatible to
+	 * has been overridden. This is to be backwards-compatible with
 	 * subclasses that predate the introduction of
 	 * -[getExtendedAttributeData:andType:forName:ofItemAtIRI:].
 	 * Without this check, this would result in an infinite loop.
@@ -217,14 +233,12 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 
 	if (class_getMethodImplementation(object_getClass(self), selector) !=
 	    class_getMethodImplementation([OFIRIHandler class], selector)) {
-		/*
-		 * Use -[performSelector:withObject:withObject:] to avoid
-		 * deprecation warning. This entire thing is purely for
-		 * backwards compatibility.
-		 */
-		*data = [self performSelector: selector
-				   withObject: name
-				   withObject: IRI];
+		/* Use -[methodForSelector:] to avoid deprecation warning. */
+		OFData *(*imp)(id, SEL, OFString *, OFIRI *) =
+		    (OFData *(*)(id, SEL, OFString *, OFIRI *))
+		    [self methodForSelector: selector];
+
+		*data = imp(self, selector, name, IRI);
 
 		if (type != NULL)
 			*type = nil;
@@ -250,12 +264,11 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 			 forName: (OFString *)name
 		     ofItemAtIRI: (OFIRI *)IRI
 {
-
 	if (type == nil) {
 		/*
 		 * Only call into
 		 * -[setExtendedAttributeData:forName:ofItemAtIRI:] if it has
-		 * been overridden. This is to be backwards-compatible to
+		 * been overridden. This is to be backwards-compatible with
 		 * subclasses that predate the introduction of
 		 * -[setExtendedAttributeData:andType:forName:ofItemAtIRI:].
 		 * Without this check, this would result in an infinite loop.
@@ -268,15 +281,14 @@ static OFMutableDictionary OF_GENERIC(OFString *, OFIRIHandler *) *handlers;
 		    class_getMethodImplementation([OFIRIHandler class],
 		    selector)) {
 			/*
-			 * Use
-			 * -[performSelector:withObject:withObject:withObject:]
-			 * to avoid deprecation warning. This entire thing is
-			 * purely for backwards compatibility.
+			 * Use -[methodForSelector:] to avoid deprecation
+			 * warning.
 			 */
-			[self performSelector: selector
-				   withObject: data
-				   withObject: name
-				   withObject: IRI];
+			void (*imp)(id, SEL, OFData *, OFString *, OFIRI *) =
+			    (void (*)(id, SEL, OFData *, OFString *, OFIRI *))
+			    [self methodForSelector: selector];
+
+			imp(self, selector, data, name, IRI);
 			return;
 		}
 	}
