@@ -73,7 +73,6 @@ OF_DIRECT_MEMBERS
 {
 	OFLHAArchive *_archive;
 	OFMutableLHAArchiveEntry *_entry;
-	OFStringEncoding _encoding;
 	OFSeekableStream *_stream;
 	OFStreamOffset _headerOffset;
 	uint64_t _bytesWritten;
@@ -82,8 +81,7 @@ OF_DIRECT_MEMBERS
 
 - (instancetype)of_initWithArchive: (OFLHAArchive *)archive
 			    stream: (OFSeekableStream *)stream
-			     entry: (OFLHAArchiveEntry *)entry
-			  encoding: (OFStringEncoding)encoding;
+			     entry: (OFLHAArchiveEntry *)entry;
 @end
 
 @implementation OFLHAArchive
@@ -91,12 +89,14 @@ OF_DIRECT_MEMBERS
 
 + (instancetype)archiveWithStream: (OFStream *)stream mode: (OFString *)mode
 {
-	return [[[self alloc] initWithStream: stream mode: mode] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithStream: stream
+								   mode: mode]);
 }
 
 + (instancetype)archiveWithIRI: (OFIRI *)IRI mode: (OFString *)mode
 {
-	return [[[self alloc] initWithIRI: IRI mode: mode] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] initWithIRI: IRI
+								mode: mode]);
 }
 
 + (OFIRI *)IRIForFilePath: (OFString *)path inArchiveWithIRI: (OFIRI *)IRI
@@ -114,7 +114,7 @@ OF_DIRECT_MEMBERS
 	self = [super init];
 
 	@try {
-		_stream = [stream retain];
+		_stream = objc_retain(stream);
 
 		if ([mode isEqual: @"r"])
 			_mode = modeRead;
@@ -139,7 +139,7 @@ OF_DIRECT_MEMBERS
 			[(OFSeekableStream *)_stream seekToOffset: -1
 							   whence: OFSeekEnd];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -157,7 +157,7 @@ OF_DIRECT_MEMBERS
 		else
 			stream = [OFIRIHandler openItemAtIRI: IRI mode: mode];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -173,7 +173,7 @@ OF_DIRECT_MEMBERS
 	if (_stream != nil)
 		[self close];
 
-	[_currentEntry release];
+	objc_release(_currentEntry);
 
 	[super dealloc];
 }
@@ -199,7 +199,7 @@ OF_DIRECT_MEMBERS
 		objc_autoreleasePoolPop(pool);
 	}
 
-	[_currentEntry release];
+	objc_release(_currentEntry);
 	_currentEntry = nil;
 
 	[(OFLHAArchiveFileReadStream *)_lastReturnedStream of_skip];
@@ -251,11 +251,12 @@ OF_DIRECT_MEMBERS
 	if (_currentEntry == nil)
 		@throw [OFInvalidArgumentException exception];
 
-	_lastReturnedStream = [[[OFLHAArchiveFileReadStream alloc]
+	_lastReturnedStream = objc_autoreleaseReturnValue(
+	    [[OFLHAArchiveFileReadStream alloc]
 	    of_initWithArchive: self
 			stream: _stream
-			 entry: _currentEntry] autorelease];
-	[_currentEntry release];
+			 entry: _currentEntry]);
+	objc_release(_currentEntry);
 	_currentEntry = nil;
 
 	return _lastReturnedStream;
@@ -282,11 +283,11 @@ OF_DIRECT_MEMBERS
 	}
 	_lastReturnedStream = nil;
 
-	_lastReturnedStream = [[[OFLHAArchiveFileWriteStream alloc]
+	_lastReturnedStream = objc_autoreleaseReturnValue(
+	    [[OFLHAArchiveFileWriteStream alloc]
 	    of_initWithArchive: self
 			stream: (OFSeekableStream *)_stream
-			 entry: entry
-		      encoding: _encoding] autorelease];
+			 entry: entry]);
 	_hasWritten = true;
 
 	return _lastReturnedStream;
@@ -309,7 +310,7 @@ OF_DIRECT_MEMBERS
 
 	_lastReturnedStream = nil;
 
-	[_stream release];
+	objc_release(_stream);
 	_stream = nil;
 }
 @end
@@ -324,8 +325,8 @@ OF_DIRECT_MEMBERS
 	@try {
 		OFString *compressionMethod;
 
-		_archive = [archive retain];
-		_stream = [stream retain];
+		_archive = objc_retain(archive);
+		_stream = objc_retain(stream);
 
 		compressionMethod = entry.compressionMethod;
 
@@ -354,7 +355,7 @@ OF_DIRECT_MEMBERS
 		    [compressionMethod isEqual: @"-lhd-"] ||
 		    [compressionMethod isEqual: @"-lz4-"] ||
 		    [compressionMethod isEqual: @"-pm0-"])
-			_decompressedStream = [stream retain];
+			_decompressedStream = objc_retain(stream);
 		else
 			@throw [OFUnsupportedVersionException
 			    exceptionWithVersion: compressionMethod];
@@ -362,7 +363,7 @@ OF_DIRECT_MEMBERS
 		_entry = [entry copy];
 		_toRead = entry.uncompressedSize;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -374,12 +375,12 @@ OF_DIRECT_MEMBERS
 	if (_stream != nil && _decompressedStream != nil)
 		[self close];
 
-	[_entry release];
+	objc_release(_entry);
 
 	if (_archive->_lastReturnedStream == self)
 		_archive->_lastReturnedStream = nil;
 
-	[_archive release];
+	objc_release(_archive);
 
 	[super dealloc];
 }
@@ -498,10 +499,10 @@ OF_DIRECT_MEMBERS
 
 	[self of_skip];
 
-	[_stream release];
+	objc_release(_stream);
 	_stream = nil;
 
-	[_decompressedStream release];
+	objc_release(_decompressedStream);
 	_decompressedStream = nil;
 
 	[super close];
@@ -512,25 +513,23 @@ OF_DIRECT_MEMBERS
 - (instancetype)of_initWithArchive: (OFLHAArchive *)archive
 			    stream: (OFSeekableStream *)stream
 			     entry: (OFLHAArchiveEntry *)entry
-			  encoding: (OFStringEncoding)encoding
 {
 	self = [super init];
 
 	@try {
-		_archive = [archive retain];
+		_archive = objc_retain(archive);
 		_entry = [entry mutableCopy];
-		_encoding = encoding;
 
 		_headerOffset = [stream seekToOffset: 0 whence: OFSeekCurrent];
-		[_entry of_writeToStream: stream encoding: _encoding];
+		[_entry of_writeToStream: stream encoding: _archive.encoding];
 
 		/*
 		 * Retain stream last, so that -[close] called by -[dealloc]
 		 * doesn't write in case of an error.
 		 */
-		_stream = [stream retain];
+		_stream = objc_retain(stream);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -542,12 +541,12 @@ OF_DIRECT_MEMBERS
 	if (_stream != nil)
 		[self close];
 
-	[_entry release];
+	objc_release(_entry);
 
 	if (_archive->_lastReturnedStream == self)
 		_archive->_lastReturnedStream = nil;
 
-	[_archive release];
+	objc_release(_archive);
 
 	[super dealloc];
 }
@@ -607,10 +606,10 @@ OF_DIRECT_MEMBERS
 
 	offset = [_stream seekToOffset: 0 whence: OFSeekCurrent];
 	[_stream seekToOffset: _headerOffset whence: OFSeekSet];
-	[_entry of_writeToStream: _stream encoding: _encoding];
+	[_entry of_writeToStream: _stream encoding: _archive.encoding];
 	[_stream seekToOffset: offset whence: OFSeekSet];
 
-	[_stream release];
+	objc_release(_stream);
 	_stream = nil;
 
 	[super close];
