@@ -24,8 +24,10 @@
 #import "OFLocale.h"
 #import "OFArray.h"
 #import "OFDictionary.h"
+#import "OFFileManager.h"
 #import "OFIRI.h"
 #import "OFNumber.h"
+#import "OFStdIOStream.h"
 #import "OFString.h"
 #import "OFString+Private.h"
 
@@ -109,7 +111,7 @@ parseLocale(char *locale, OFStringEncoding *encoding,
 static bool
 evaluateCondition(OFString *condition_, OFDictionary *variables)
 {
-	OFMutableString *condition = [[condition_ mutableCopy] autorelease];
+	OFMutableString *condition = objc_autorelease([condition_ mutableCopy]);
 	OFMutableArray *tokens, *operators, *stack;
 
 	/* Empty condition is the fallback that's always true */
@@ -412,7 +414,7 @@ evaluateArray(OFArray *array, OFDictionary *variables)
 	 * break old applications, this method needs to just return the
 	 * singleton now.
 	 */
-	[self release];
+	objc_release(self);
 
 	return [OFLocale currentLocale];
 }
@@ -450,8 +452,8 @@ evaluateArray(OFArray *array, OFDictionary *variables)
 			parseLocale(messagesLocale, &_encoding,
 			    &_languageCode, &_countryCode);
 
-			[_languageCode retain];
-			[_countryCode retain];
+			objc_retain(_languageCode);
+			objc_retain(_countryCode);
 
 			objc_autoreleasePoolPop(pool);
 		}
@@ -523,8 +525,15 @@ evaluateArray(OFArray *array, OFDictionary *variables)
 
 		objc_autoreleasePoolPop(pool);
 #endif
+
+		if (OFStdIn.hasTerminal)
+			OFStdIn.encoding = _encoding;
+		if (OFStdOut.hasTerminal)
+			OFStdOut.encoding = _encoding;
+		if (OFStdErr.hasTerminal)
+			OFStdErr.encoding = _encoding;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -536,7 +545,8 @@ OF_SINGLETON_METHODS
 - (void)addLocalizationDirectoryIRI: (OFIRI *)IRI
 {
 	void *pool;
-	OFIRI *mapIRI, *localizationIRI;
+	OFFileManager *fileManager;
+	OFIRI *mapIRI, *localizationIRI, *compressedLocalizationIRI;
 	OFString *languageCode, *countryCode, *localizationFile;
 	OFDictionary *map;
 
@@ -571,8 +581,19 @@ OF_SINGLETON_METHODS
 		return;
 	}
 
+	fileManager = [OFFileManager defaultManager];
+
 	localizationIRI = [IRI IRIByAppendingPathComponent:
 	    [localizationFile stringByAppendingString: @".json"]];
+	compressedLocalizationIRI = [IRI IRIByAppendingPathComponent:
+	    [localizationFile stringByAppendingString: @".json.gz"]];
+
+	if (![fileManager fileExistsAtIRI: localizationIRI] &&
+	    [fileManager fileExistsAtIRI: compressedLocalizationIRI]) {
+		OFMutableIRI *tmp = [OFMutableIRI IRIWithScheme: @"gzip"];
+		tmp.path = compressedLocalizationIRI.string;
+		localizationIRI = tmp;
+	}
 
 	[_localizedStrings addObject: [[OFString stringWithContentsOfIRI:
 	    localizationIRI] objectByParsingJSON]];
