@@ -340,8 +340,7 @@ convert(OFMutableString *self, char (*startFunction)(char),
 	va_list arguments;
 
 	va_start(arguments, format);
-	[self appendFormat: format
-		 arguments: arguments];
+	[self appendFormat: format arguments: arguments];
 	va_end(arguments);
 }
 
@@ -444,8 +443,7 @@ convert(OFMutableString *self, char (*startFunction)(char),
 	if (string == nil || replacement == nil)
 		@throw [OFInvalidArgumentException exception];
 
-	if (range.length > SIZE_MAX - range.location ||
-	    range.location + range.length > self.length)
+	if (OFEndOfRange(range) > self.length)
 		@throw [OFOutOfRangeException exception];
 
 	if (searchLength > range.length) {
