@@ -38,7 +38,8 @@
 
 + (instancetype)entryWithFileName: (OFString *)fileName
 {
-	return [[[self alloc] initWithFileName: fileName] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithFileName: fileName]);
 }
 
 - (instancetype)initWithFileName: (OFString *)fileName
@@ -48,7 +49,7 @@
 	@try {
 		_fileName = [fileName copy];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -68,28 +69,28 @@
 {
 	OFString *old = _fileName;
 	_fileName = [fileName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setPOSIXPermissions: (OFNumber *)POSIXPermissions
 {
 	OFNumber *old = _POSIXPermissions;
-	_POSIXPermissions = [POSIXPermissions retain];
-	[old release];
+	_POSIXPermissions = objc_retain(POSIXPermissions);
+	objc_release(old);
 }
 
 - (void)setOwnerAccountID: (OFNumber *)ownerAccountID
 {
 	OFNumber *old = _ownerAccountID;
-	_ownerAccountID = [ownerAccountID retain];
-	[old release];
+	_ownerAccountID = objc_retain(ownerAccountID);
+	objc_release(old);
 }
 
 - (void)setGroupOwnerAccountID: (OFNumber *)groupOwnerAccountID
 {
 	OFNumber *old = _groupOwnerAccountID;
-	_groupOwnerAccountID = [groupOwnerAccountID retain];
-	[old release];
+	_groupOwnerAccountID = objc_retain(groupOwnerAccountID);
+	objc_release(old);
 }
 
 - (void)setCompressedSize: (unsigned long long)compressedSize
@@ -105,8 +106,8 @@
 - (void)setModificationDate: (OFDate *)modificationDate
 {
 	OFDate *old = _modificationDate;
-	_modificationDate = [modificationDate retain];
-	[old release];
+	_modificationDate = objc_retain(modificationDate);
+	objc_release(old);
 }
 
 - (void)setType: (OFTarArchiveEntryType)type
@@ -118,21 +119,21 @@
 {
 	OFString *old = _targetFileName;
 	_targetFileName = [targetFileName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setOwnerAccountName: (OFString *)ownerAccountName
 {
 	OFString *old = _ownerAccountName;
 	_ownerAccountName = [ownerAccountName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setGroupOwnerAccountName: (OFString *)groupOwnerAccountName
 {
 	OFString *old = _groupOwnerAccountName;
 	_groupOwnerAccountName = [groupOwnerAccountName copy];
-	[old release];
+	objc_release(old);
 }
 
 - (void)setDeviceMajor: (unsigned long)deviceMajor
