@@ -30,6 +30,7 @@
 #include <stdint.h>
 #include <stdbool.h>
 #include <limits.h>
+#include <math.h>
 
 #include "macros.h"
 
@@ -52,6 +53,11 @@ OF_ASSUME_NONNULL_BEGIN
 
 /** @file */
 
+/**
+ * @brief A special not found index.
+ */
+static const size_t OFNotFound = SIZE_MAX;
+
 /**
  * @brief A result of a comparison.
  */
@@ -148,6 +154,90 @@ OFEqualRanges(OFRange range1, OFRange range2)
 	return true;
 }
 
+/**
+ * @brief Returns the end of the range, which is its location + its length.
+ *
+ * @param range The range whose end to return
+ * @return The end of the range
+ */
+static OF_INLINE size_t
+OFEndOfRange(OFRange range)
+{
+	if (range.length > SIZE_MAX - range.location) {
+		extern void OF_NO_RETURN_FUNC _OFThrowOutOfRangeException(void);
+		_OFThrowOutOfRangeException();
+	}
+
+	return range.location + range.length;
+}
+
+/**
+ * @brief Returns whether the specified location is in the specified range.
+ *
+ * @param location The location
+ * @param range The range
+ * @return Whether the specified location is in the specified range
+ */
+static OF_INLINE bool
+OFLocationInRange(size_t location, OFRange range)
+{
+	return (location >= range.location &&
+	    location < OFEndOfRange(range));
+}
+
+/**
+ * @brief Returns the intersection of the two ranges or @ref OFNotFound and
+ *	  length 0 if they don't intersect.
+ *
+ * @param range1 The first range
+ * @param range2 The second range
+ * @return The intersection of both ranges
+ */
+static OF_INLINE OFRange
+OFIntersectionRange(OFRange range1, OFRange range2)
+{
+	OFRange range;
+
+	if (range1.location >= OFEndOfRange(range2) ||
+	    range2.location >= OFEndOfRange(range1))
+		return OFMakeRange(OFNotFound, 0);
+
+	range.location = (range1.location > range2.location
+	    ? range1.location : range2.location);
+	range.length = (OFEndOfRange(range1) < OFEndOfRange(range2))
+	    ? OFEndOfRange(range1) - range.location
+	    : OFEndOfRange(range2) - range.location;
+
+	return range;
+}
+
+/**
+ * @brief Returns the union of the two ranges if they are overlapping or
+ *	  adjacent, otherwise returns a range with location @ref OFNotFound and
+ *	  length 0.
+ *
+ * @param range1 The first range
+ * @param range2 The second range
+ * @return The two ranges merged
+ */
+static OF_INLINE OFRange
+OFUnionRange(OFRange range1, OFRange range2)
+{
+	OFRange range;
+
+	if (range1.location > OFEndOfRange(range2) ||
+	    range2.location > OFEndOfRange(range1))
+		return OFMakeRange(OFNotFound, 0);
+
+	range.location = (range1.location < range2.location
+	    ? range1.location : range2.location);
+	range.length = (OFEndOfRange(range1) > OFEndOfRange(range2))
+	    ? OFEndOfRange(range1) - range.location
+	    : OFEndOfRange(range2) - range.location;
+
+	return range;
+}
+
 /**
  * @brief A time interval in seconds.
  */
@@ -348,6 +438,77 @@ OFEqualVectors3D(OFVector3D vector1, OFVector3D vector2)
 	return true;
 }
 
+/**
+ * @brief Adds the two specified vectors.
+ *
+ * @param vector1 The vector to add to
+ * @param vector2 The vector to add
+ * @return The sum of the two vectors
+ */
+static OF_INLINE OFVector3D
+OFAddVectors3D(OFVector3D vector1, OFVector3D vector2)
+{
+	return OFMakeVector3D(vector1.x + vector2.x, vector1.y + vector2.y,
+	    vector1.z + vector2.z);
+}
+
+/**
+ * @brief Subtracts the second vector from the first vector.
+ *
+ * @param vector1 The vector to subtract from
+ * @param vector2 The vector to subtract
+ * @return The second vector subtracted from the first vector
+ */
+static OF_INLINE OFVector3D
+OFSubtractVectors3D(OFVector3D vector1, OFVector3D vector2)
+{
+	return OFMakeVector3D(vector1.x - vector2.x, vector1.y - vector2.y,
+	    vector1.z - vector2.z);
+}
+
+/**
+ * @brief Multiplies the specified vector with a scalar.
+ *
+ * @param vector The vector
+ * @param scalar The scalar to multiply with
+ * @return The vector multiplied with the scalar
+ */
+static OF_INLINE OFVector3D
+OFMultiplyVector3D(OFVector3D vector, float scalar)
+{
+	return OFMakeVector3D(vector.x * scalar, vector.y * scalar,
+	    vector.z * scalar);
+}
+
+/**
+ * @brief Calculates the dot product of the two specified vectors.
+ *
+ * @param vector1 The first vector
+ * @param vector2 The second vector
+ * @return The dot product of the two vectors
+ */
+static OF_INLINE float
+OFDotProductOfVectors3D(OFVector3D vector1, OFVector3D vector2)
+{
+	return vector1.x * vector2.x + vector1.y * vector2.y +
+	    vector1.z * vector2.z;
+}
+
+/**
+ * @brief Calculates the distance between two vectors
+ *
+ * @param vector1 The first vector
+ * @param vector2 The second vector
+ * @return The distance of the two vectors
+ */
+static OF_INLINE float
+OFDistanceOfVectors3D(OFVector3D vector1, OFVector3D vector2)
+{
+	OFVector3D difference = OFSubtractVectors3D(vector1, vector2);
+
+	return sqrtf(OFDotProductOfVectors3D(difference, difference));
+}
+
 /**
  * @struct OFVector4D OFObject.h ObjFW/ObjFW.h
  *
@@ -406,6 +567,77 @@ OFEqualVectors4D(OFVector4D vector1, OFVector4D vector2)
 	return true;
 }
 
+/**
+ * @brief Adds the two specified vectors.
+ *
+ * @param vector1 The vector to add to
+ * @param vector2 The vector to add
+ * @return The sum of the two vectors
+ */
+static OF_INLINE OFVector4D
+OFAddVectors4D(OFVector4D vector1, OFVector4D vector2)
+{
+	return OFMakeVector4D(vector1.x + vector2.x, vector1.y + vector2.y,
+	    vector1.z + vector2.z, vector1.w + vector2.w);
+}
+
+/**
+ * @brief Subtracts the second vector from the first vector.
+ *
+ * @param vector1 The vector to subtract from
+ * @param vector2 The vector to subtract
+ * @return The second vector subtracted from the first vector
+ */
+static OF_INLINE OFVector4D
+OFSubtractVectors4D(OFVector4D vector1, OFVector4D vector2)
+{
+	return OFMakeVector4D(vector1.x - vector2.x, vector1.y - vector2.y,
+	    vector1.z - vector2.z, vector1.w - vector2.w);
+}
+
+/**
+ * @brief Multiplies the specified vector with a scalar.
+ *
+ * @param vector The vector
+ * @param scalar The scalar to multiply with
+ * @return The vector multiplied with the scalar
+ */
+static OF_INLINE OFVector4D
+OFMultiplyVector4D(OFVector4D vector, float scalar)
+{
+	return OFMakeVector4D(vector.x * scalar, vector.y * scalar,
+	    vector.z * scalar, vector.w * scalar);
+}
+
+/**
+ * @brief Calculates the dot product of the two specified vectors.
+ *
+ * @param vector1 The first vector
+ * @param vector2 The second vector
+ * @return The dot product of the two vectors
+ */
+static OF_INLINE float
+OFDotProductOfVectors4D(OFVector4D vector1, OFVector4D vector2)
+{
+	return vector1.x * vector2.x + vector1.y * vector2.y +
+	    vector1.z * vector2.z + vector1.w * vector2.w;
+}
+
+/**
+ * @brief Calculates the distance between two vectors
+ *
+ * @param vector1 The first vector
+ * @param vector2 The second vector
+ * @return The distance of the two vectors
+ */
+static OF_INLINE float
+OFDistanceOfVectors4D(OFVector4D vector1, OFVector4D vector2)
+{
+	OFVector4D difference = OFSubtractVectors4D(vector1, vector2);
+
+	return sqrtf(OFDotProductOfVectors4D(difference, difference));
+}
+
 /**
  * @brief Adds the specified byte to the hash.
  *
@@ -456,8 +688,6 @@ OFHashFinalize(unsigned long *_Nonnull hash)
 	*hash = tmp;
 }
 
-static const size_t OFNotFound = SIZE_MAX;
-
 @class OFMethodSignature;
 @class OFString;
 @class OFThread;
@@ -941,7 +1171,7 @@ OF_ROOT_CLASS
  * @try {
  *         // Custom initialization code goes here.
  * } @catch (id e) {
- *         [self release];
+ *         objc_release(self);
  *         @throw e;
  * }
  *
@@ -1416,7 +1646,7 @@ extern "C" {
  *				address space
  */
 extern void *_Nullable OFAllocMemory(size_t count, size_t size)
-    OF_WARN_UNUSED_RESULT;
+    OF_MALLOC_FUNC OF_WARN_UNUSED_RESULT;
 
 /**
  * @brief Allocates memory for the specified number of items of the specified
@@ -1433,7 +1663,7 @@ extern void *_Nullable OFAllocMemory(size_t count, size_t size)
  *				address space
  */
 extern void *_Nullable OFAllocZeroedMemory(size_t count, size_t size)
-    OF_WARN_UNUSED_RESULT;
+    OF_MALLOC_FUNC OF_WARN_UNUSED_RESULT;
 
 /**
  * @brief Resizes memory to the specified number of items of the specified size.
@@ -1467,6 +1697,27 @@ extern void OFFreeMemory(void *_Nullable pointer);
 #ifdef OF_APPLE_RUNTIME
 extern void *_Null_unspecified objc_autoreleasePoolPush(void);
 extern void objc_autoreleasePoolPop(void *_Null_unspecified pool);
+extern id _Nullable objc_retain(id _Nullable object);
+extern id _Nullable objc_retainBlock(id _Nullable block);
+extern id _Nullable objc_retainAutorelease(id _Nullable object);
+extern void objc_release(id _Nullable object);
+extern id _Nullable objc_autorelease(id _Nullable object);
+extern id _Nullable objc_autoreleaseReturnValue(id _Nullable object);
+extern id _Nullable objc_retainAutoreleaseReturnValue(id _Nullable object);
+extern id _Nullable objc_retainAutoreleasedReturnValue(id _Nullable object);
+extern id _Nullable objc_storeStrong(id _Nullable *_Nonnull object,
+    id _Nullable value);
+extern id _Nullable objc_storeWeak(id _Nullable *_Nonnull object,
+    id _Nullable value);
+extern id _Nullable objc_loadWeakRetained(id _Nullable *_Nonnull object);
+extern _Nullable id objc_initWeak(id _Nullable *_Nonnull object,
+    id _Nullable value);
+extern void objc_destroyWeak(id _Nullable *_Nonnull object);
+extern id _Nullable objc_loadWeak(id _Nullable *_Nonnull object);
+extern void objc_copyWeak(id _Nullable *_Nonnull dest,
+    id _Nullable *_Nonnull src);
+extern void objc_moveWeak(id _Nullable *_Nonnull dest,
+    id _Nullable *_Nonnull src);
 # ifdef OF_DECLARE_CONSTRUCT_INSTANCE
 extern id _Nullable objc_constructInstance(Class _Nullable class_,
     void *_Nullable bytes);
@@ -1513,14 +1764,14 @@ extern id OFAllocObject(Class class_, size_t extraSize, size_t extraAlignment,
  *
  *     - (void)abstractMethod
  *     {
- *     	OF_UNRECOGNIZED_SELECTOR
+ *             OF_UNRECOGNIZED_SELECTOR
  *     }
  *
  * However, do not use this for init methods. Instead, use the following:
  *
  *     - (instancetype)init
  *     {
- *     	OF_INVALID_INIT_METHOD
+ *             OF_INVALID_INIT_METHOD
  *     }
  *
  * @param self The object which does not have the method
