@@ -156,8 +156,8 @@ processBlock(uint32_t *state, uint32_t *buffer)
 
 + (instancetype)hashWithAllowsSwappableMemory: (bool)allowsSwappableMemory
 {
-	return [[[self alloc] initWithAllowsSwappableMemory:
-	    allowsSwappableMemory] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc]
+	    initWithAllowsSwappableMemory: allowsSwappableMemory]);
 }
 
 - (instancetype)initWithAllowsSwappableMemory: (bool)allowsSwappableMemory
@@ -173,7 +173,7 @@ processBlock(uint32_t *state, uint32_t *buffer)
 
 		[self of_resetState];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -192,7 +192,7 @@ processBlock(uint32_t *state, uint32_t *buffer)
 
 - (void)dealloc
 {
-	[_iVarsData release];
+	objc_release(_iVarsData);
 
 	[super dealloc];
 }
