@@ -147,8 +147,8 @@ processBlock(uint64_t *state, uint64_t *buffer)
 
 + (instancetype)hashWithAllowsSwappableMemory: (bool)allowsSwappableMemory
 {
-	return [[[self alloc] initWithAllowsSwappableMemory:
-	    allowsSwappableMemory] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc]
+	    initWithAllowsSwappableMemory: allowsSwappableMemory]);
 }
 
 - (instancetype)initWithAllowsSwappableMemory: (bool)allowsSwappableMemory
@@ -169,7 +169,7 @@ processBlock(uint64_t *state, uint64_t *buffer)
 
 		[self of_resetState];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -188,7 +188,7 @@ processBlock(uint64_t *state, uint64_t *buffer)
 
 - (void)dealloc
 {
-	[_iVarsData release];
+	objc_release(_iVarsData);
 
 	[super dealloc];
 }
