@@ -77,7 +77,7 @@
 		_maxFD = (int)_cancelFD[0];
 #endif
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -236,12 +236,14 @@
 
 	Permit();
 
-	if (events < 0)
-		@throw [OFObserveKernelEventsFailedException
-		    exceptionWithObserver: self
-				    errNo: _OFSocketErrNo()];
+	if (events < 0) {
+		int errNo = _OFSocketErrNo();
 
-	if (execSignalMask != 0 &&
+		if (errNo != EINTR)
+			@throw [OFObserveKernelEventsFailedException
+			    exceptionWithObserver: self
+					    errNo: errNo];
+	} else if (execSignalMask != 0 &&
 	    [_delegate respondsToSelector: @selector(execSignalWasReceived:)])
 		[_delegate execSignalWasReceived: execSignalMask];
 #else
@@ -252,7 +254,7 @@
 		if (errNo != EINTR)
 			@throw [OFObserveKernelEventsFailedException
 			    exceptionWithObserver: self
-					    errNo: _OFSocketErrNo()];
+					    errNo: errNo];
 	}
 
 	if (FD_ISSET(_cancelFD[0], &readFDs)) {
@@ -270,7 +272,7 @@
 	pool = objc_autoreleasePoolPush();
 
 	for (id <OFReadyForReadingObserving> object in
-	    [[_readObjects copy] autorelease]) {
+	    objc_autorelease([_readObjects copy])) {
 		void *pool2 = objc_autoreleasePoolPush();
 		int fd = object.fileDescriptorForReading;
 
@@ -283,7 +285,7 @@
 	}
 
 	for (id <OFReadyForWritingObserving> object in
-	    [[_writeObjects copy] autorelease]) {
+	    objc_autorelease([_writeObjects copy])) {
 		void *pool2 = objc_autoreleasePoolPush();
 		int fd = object.fileDescriptorForWriting;
 
