@@ -24,10 +24,10 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern char *_Nullable _OFStrDup(const char *_Nonnull) OF_VISIBILITY_HIDDEN;
-extern size_t _OFUTF8StringEncode(OFUnichar, char *) OF_VISIBILITY_HIDDEN;
+extern char *_Nullable _OFStrDup(const char *_Nonnull) OF_VISIBILITY_INTERNAL;
+extern size_t _OFUTF8StringEncode(OFUnichar, char *) OF_VISIBILITY_INTERNAL;
 extern ssize_t _OFUTF8StringDecode(const char *, size_t, OFUnichar *)
-    OF_VISIBILITY_HIDDEN;
+    OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
