@@ -49,7 +49,7 @@
 		_weight = weight;
 		_target = [target copy];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -58,7 +58,7 @@
 
 - (void)dealloc
 {
-	[_target release];
+	objc_release(_target);
 
 	[super dealloc];
 }
