@@ -203,8 +203,8 @@ resolveAttributeNamespace(OFXMLAttribute *attribute, OFArray *namespaces,
 		    exceptionWithPrefix: attributePrefix
 				 parser: self];
 
-	[attribute->_namespace release];
-	attribute->_namespace = [attributeNS retain];
+	objc_release(attribute->_namespace);
+	attribute->_namespace = objc_retain(attributeNS);
 }
 
 @implementation OFXMLParser
@@ -212,7 +212,7 @@ resolveAttributeNamespace(OFXMLAttribute *attribute, OFArray *namespaces,
 
 + (instancetype)parser
 {
-	return [[[self alloc] init] autorelease];
+	return objc_autoreleaseReturnValue([[self alloc] init]);
 }
 
 - (instancetype)init
@@ -241,7 +241,7 @@ resolveAttributeNamespace(OFXMLAttribute *attribute, OFArray *namespaces,
 
 		objc_autoreleasePoolPop(pool);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -250,14 +250,14 @@ resolveAttributeNamespace(OFXMLAttribute *attribute, OFArray *namespaces,
 
 - (void)dealloc
 {
-	[_buffer release];
-	[_name release];
-	[_prefix release];
-	[_namespaces release];
-	[_attributes release];
-	[_attributeName release];
-	[_attributePrefix release];
-	[_previous release];
+	objc_release(_buffer);
+	objc_release(_name);
+	objc_release(_prefix);
+	objc_release(_namespaces);
+	objc_release(_attributes);
+	objc_release(_attributeName);
+	objc_release(_attributePrefix);
+	objc_release(_previous);
 
 	[super dealloc];
 }
@@ -295,13 +295,13 @@ resolveAttributeNamespace(OFXMLAttribute *attribute, OFArray *namespaces,
 
 - (void)parseStream: (OFStream *)stream
 {
-	size_t pageSize = [OFSystemInfo pageSize];
-	char *buffer = OFAllocMemory(1, pageSize);
+	const size_t bufferSize = 16384;
+	char *buffer = OFAllocMemory(1, bufferSize);
 
 	@try {
 		while (!stream.atEndOfStream) {
 			size_t length = [stream readIntoBuffer: buffer
-							length: pageSize];
+							length: bufferSize];
 			[self parseBuffer: buffer length: length];
 		}
 	} @finally {
@@ -503,26 +503,26 @@ inProcessingInstructionState(OFXMLParser *self)
 		self->_level = 1;
 	else if (self->_level == 1 && self->_data[self->_i] == '>') {
 		void *pool = objc_autoreleasePoolPush();
-		OFString *PI, *target, *text = nil;
+		OFString *PI_, *target, *text = nil;
 		OFCharacterSet *whitespaceCS;
 		size_t pos;
 
 		appendToBuffer(self->_buffer, self->_data + self->_last,
 		    self->_encoding, self->_i - self->_last);
-		PI = transformString(self, self->_buffer, 1, false);
+		PI_ = transformString(self, self->_buffer, 1, false);
 
 		whitespaceCS = [OFCharacterSet
 		    characterSetWithCharactersInString: @" \r\n\r"];
-		pos = [PI rangeOfCharacterFromSet: whitespaceCS].location;
+		pos = [PI_ rangeOfCharacterFromSet: whitespaceCS].location;
 		if (pos != OFNotFound) {
-			target = [PI substringToIndex: pos];
-			text = [[PI substringFromIndex: pos + 1]
+			target = [PI_ substringToIndex: pos];
+			text = [[PI_ substringFromIndex: pos + 1]
 			    stringByDeletingEnclosingWhitespaces];
 
 			if (text.length == 0)
 				text = nil;
 		} else
-			target = PI;
+			target = PI_;
 
 		if ([target caseInsensitiveCompare: @"xml"] == OFOrderedSame)
 			if (!parseXMLProcessingInstruction(self, text))
@@ -613,8 +613,8 @@ inTagNameState(OFXMLParser *self)
 		} else
 			[self->_previous addObject: bufferString];
 
-		[self->_name release];
-		[self->_prefix release];
+		objc_release(self->_name);
+		objc_release(self->_prefix);
 		self->_name = self->_prefix = nil;
 
 		self->_state = (self->_data[self->_i] == '/'
@@ -692,8 +692,8 @@ inCloseTagNameState(OFXMLParser *self)
 	objc_autoreleasePoolPop(pool);
 
 	[self->_namespaces removeLastObject];
-	[self->_name release];
-	[self->_prefix release];
+	objc_release(self->_name);
+	objc_release(self->_prefix);
 	self->_name = self->_prefix = nil;
 
 	self->_last = self->_i + 1;
@@ -771,8 +771,8 @@ inTagState(OFXMLParser *self)
 
 	objc_autoreleasePoolPop(pool);
 
-	[self->_name release];
-	[self->_prefix release];
+	objc_release(self->_name);
+	objc_release(self->_prefix);
 	[self->_attributes removeAllObjects];
 	self->_name = self->_prefix = nil;
 
@@ -897,8 +897,8 @@ inAttributeValueState(OFXMLParser *self)
 	objc_autoreleasePoolPop(pool);
 
 	[self->_buffer removeAllItems];
-	[self->_attributeName release];
-	[self->_attributePrefix release];
+	objc_release(self->_attributeName);
+	objc_release(self->_attributePrefix);
 	self->_attributeName = self->_attributePrefix = nil;
 
 	self->_last = self->_i + 1;
