@@ -163,7 +163,7 @@
 				[stream readIntoBuffer: attributes
 					   exactLength: 3];
 
-				if (attributes[2] & (1 << 6)) {
+				if ((attributes[2] & 0xC0) == 0x40) {
 					uint16_t mode = (attributes[0] |
 					    (attributes[1] << 8)) & 0777;
 
@@ -411,6 +411,15 @@
 	strncpy(fileNameBuffer, [_fileName cStringWithEncoding: encoding], 12);
 	[data addItems: fileNameBuffer count: 13];
 
+	/*
+	 * Include \0. Needs to be done here so the written variable length is
+	 * correct.
+	 */
+	if (fileNameLength > 0)
+		fileNameLength++;
+	if (directoryNameLength > 0)
+		directoryNameLength++;
+
 	/* Variable length. */
 	tmp16 = OFToLittleEndian16(fileNameLength + directoryNameLength + 4 +
 	    (_POSIXPermissions != nil ? 3 : 0));
@@ -424,12 +433,6 @@
 	 */
 	[data increaseCountBy: 2];
 
-	/* Include \0 */
-	if (fileNameLength > 0)
-		fileNameLength++;
-	if (directoryNameLength > 0)
-		directoryNameLength++;
-
 	tmp8 = (uint8_t)fileNameLength;
 	[data addItem: &tmp8];
 	tmp8 = (uint8_t)directoryNameLength;
