@@ -34,9 +34,9 @@
 		if (array == nil)
 			@throw [OFInvalidArgumentException exception];
 
-		_array = [array retain];
+		_array = objc_retain(array);
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -45,7 +45,7 @@
 
 - (void)dealloc
 {
-	[_array release];
+	objc_release(_array);
 
 	[super dealloc];
 }
