@@ -26,14 +26,14 @@
 {
 	self = [super init];
 
-	_data = [data retain];
+	_data = objc_retain(data);
 
 	return self;
 }
 
 - (void)dealloc
 {
-	[_data release];
+	objc_release(_data);
 
 	[super dealloc];
 }
