@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -17,15 +17,7 @@
  * <https://www.gnu.org/licenses/>.
  */
 
-#ifdef OBJFWBRIDGE_LOCAL_INCLUDES
-# import "OFEnumerator.h"
-#else
-# if defined(__has_feature) && __has_feature(modules)
-@import ObjFW;
-# else
-#  import <ObjFW/OFEnumerator.h>
-# endif
-#endif
+#import "OFEnumerator.h"
 
 OF_ASSUME_NONNULL_BEGIN
 
