@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -23,7 +23,7 @@
 
 #import "common.h"
 
-const OFChar16 _OFCodepage850Table[] OF_VISIBILITY_HIDDEN = {
+const OFChar16 _OFCodepage850Table[] OF_VISIBILITY_INTERNAL = {
 	0x00C7, 0x00FC, 0x00E9, 0x00E2, 0x00E4, 0x00E0, 0x00E5, 0x00E7,
 	0x00EA, 0x00EB, 0x00E8, 0x00EF, 0x00EE, 0x00EC, 0x00C4, 0x00C5,
 	0x00C9, 0x00E6, 0x00C6, 0x00F4, 0x00F6, 0x00F2, 0x00FB, 0x00F9,
@@ -41,7 +41,7 @@ const OFChar16 _OFCodepage850Table[] OF_VISIBILITY_HIDDEN = {
 	0x00AD, 0x00B1, 0x2017, 0x00BE, 0x00B6, 0x00A7, 0x00F7, 0x00B8,
 	0x00B0, 0x00A8, 0x00B7, 0x00B9, 0x00B3, 0x00B2, 0x25A0, 0x00A0
 };
-const size_t _OFCodepage850TableOffset OF_VISIBILITY_HIDDEN =
+const size_t _OFCodepage850TableOffset OF_VISIBILITY_INTERNAL =
     256 - (sizeof(_OFCodepage850Table) / sizeof(*_OFCodepage850Table));
 
 static const unsigned char page0[] = {
@@ -107,7 +107,7 @@ static const unsigned char page25[] = {
 };
 static const uint8_t page25Start = 0x00;
 
-bool OF_VISIBILITY_HIDDEN
+bool OF_VISIBILITY_INTERNAL
 _OFUnicodeToCodepage850(const OFUnichar *input, unsigned char *output,
     size_t length, bool lossy, bool insecure)
 {
