@@ -32,7 +32,9 @@
 
 + (instancetype)exceptionWithSocket: (id)sock errNo: (int)errNo
 {
-	return [[[self alloc] initWithSocket: sock errNo: errNo] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithSocket: sock
+				   errNo: errNo]);
 }
 
 - (instancetype)init
@@ -45,10 +47,10 @@
 	self = [super init];
 
 	@try {
-		_socket = [sock retain];
+		_socket = objc_retain(sock);
 		_errNo = errNo;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -57,7 +59,7 @@
 
 - (void)dealloc
 {
-	[_socket release];
+	objc_release(_socket);
 
 	[super dealloc];
 }
