@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -75,7 +75,7 @@ OF_ASSUME_NONNULL_BEGIN
 extern "C" {
 #endif
 extern OFString *_OFDNSResolverErrorCodeDescription(
-    OFDNSResolverErrorCode errorCode) OF_VISIBILITY_HIDDEN;
+    OFDNSResolverErrorCode errorCode) OF_VISIBILITY_INTERNAL;
 #ifdef __cplusplus
 }
 #endif
