@@ -32,7 +32,8 @@
 
 + (instancetype)exceptionWithObject: (id)object
 {
-	return [[[self alloc] initWithObject: object] autorelease];
+	return objc_autoreleaseReturnValue(
+	    [[self alloc] initWithObject: object]);
 }
 
 - (instancetype)init
@@ -44,14 +45,14 @@
 {
 	self = [super init];
 
-	_object = [object retain];
+	_object = objc_retain(object);
 
 	return self;
 }
 
 - (void)dealloc
 {
-	[_object release];
+	objc_release(_object);
 
 	[super dealloc];
 }
