@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2025 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -21,10 +21,13 @@
 
 OF_ASSUME_NONNULL_BEGIN
 
+OF_DIRECT_MEMBERS
 @interface OHGameControllerAxis ()
 #if defined(OF_LINUX) && defined(OF_HAVE_FILES)
 @property (nonatomic, setter=oh_setMinRawValue:) int32_t oh_minRawValue;
 @property (nonatomic, setter=oh_setMaxRawValue:) int32_t oh_maxRawValue;
+@property (nonatomic, getter=oh_isInverted, setter=oh_setInverted:)
+    bool oh_inverted;
 #endif
 @end
 
