@@ -432,6 +432,8 @@ queryNetworkInterfaceIPXAddresses(OFMutableDictionary *ret)
 			    unsignedLongLongValueWithBase: 16];
 		} @catch (OFInvalidFormatException *e) {
 			continue;
+		} @catch (OFOutOfRangeException *e) {
+			continue;
 		}
 
 		if (network > 0xFFFFFFFF || nodeLong > 0xFFFFFFFFFFFF)
@@ -528,6 +530,8 @@ queryNetworkInterfaceAppleTalkAddresses(OFMutableDictionary *ret)
 			    unsignedCharValueWithBase: 16];
 		} @catch (OFInvalidFormatException *e) {
 			continue;
+		} @catch (OFOutOfRangeException *e) {
+			continue;
 		}
 
 		if (network > 0xFFFF || node > 0xFF)
@@ -739,10 +743,10 @@ next:
 		[interface makeImmutable];
 
 	[ret makeImmutable];
-	[ret retain];
+	objc_retain(ret);
 
 	objc_autoreleasePoolPop(pool);
 
-	return [ret autorelease];
+	return objc_autoreleaseReturnValue(ret);
 }
 @end
