@@ -24,7 +24,7 @@
 
 #import "OFTLSKey.h"
 
-extern int OFTLSKeyNew(OFTLSKey *key) OF_VISIBILITY_HIDDEN;
-extern int OFTLSKeyFree(OFTLSKey key) OF_VISIBILITY_HIDDEN;
+extern int OFTLSKeyNew(OFTLSKey *key) OF_VISIBILITY_INTERNAL;
+extern int OFTLSKeyFree(OFTLSKey key) OF_VISIBILITY_INTERNAL;
 
 #include "../OFTLSKey.m"
