@@ -26,13 +26,13 @@
 #import "private.h"
 
 struct objc_sparsearray *
-objc_sparsearray_new(uint8_t levels)
+_objc_sparsearray_new(uint8_t levels)
 {
 	struct objc_sparsearray *sparsearray;
 
 	if ((sparsearray = calloc(1, sizeof(*sparsearray))) == NULL ||
 	    (sparsearray->data = calloc(1, sizeof(*sparsearray->data))) == NULL)
-		OBJC_ERROR("Failed to allocate memory for sparse array!");
+		_OBJC_ERROR("Failed to allocate memory for sparse array!");
 
 	sparsearray->levels = levels;
 
@@ -40,7 +40,7 @@ objc_sparsearray_new(uint8_t levels)
 }
 
 void *
-objc_sparsearray_get(struct objc_sparsearray *sparsearray, uintptr_t idx)
+_objc_sparsearray_get(struct objc_sparsearray *sparsearray, uintptr_t idx)
 {
 	struct objc_sparsearray_data *iter = sparsearray->data;
 
@@ -56,7 +56,7 @@ objc_sparsearray_get(struct objc_sparsearray *sparsearray, uintptr_t idx)
 }
 
 void
-objc_sparsearray_set(struct objc_sparsearray *sparsearray, uintptr_t idx,
+_objc_sparsearray_set(struct objc_sparsearray *sparsearray, uintptr_t idx,
     void *value)
 {
 	struct objc_sparsearray_data *iter = sparsearray->data;
@@ -68,7 +68,7 @@ objc_sparsearray_set(struct objc_sparsearray *sparsearray, uintptr_t idx,
 		if (iter->next[j] == NULL)
 			if ((iter->next[j] = calloc(1,
 			    sizeof(struct objc_sparsearray_data))) == NULL)
-				OBJC_ERROR("Failed to allocate memory for "
+				_OBJC_ERROR("Failed to allocate memory for "
 				    "sparse array!");
 
 		iter = iter->next[j];
@@ -90,7 +90,7 @@ freeSparsearrayData(struct objc_sparsearray_data *data, uint8_t depth)
 }
 
 void
-objc_sparsearray_free(struct objc_sparsearray *sparsearray)
+_objc_sparsearray_free(struct objc_sparsearray *sparsearray)
 {
 	freeSparsearrayData(sparsearray->data, sparsearray->levels);
 	free(sparsearray);
