@@ -116,7 +116,7 @@ errToErrorCode(const SSL *SSL_)
 		 */
 		_underlyingStream.buffersWrites = true;
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -128,7 +128,7 @@ errToErrorCode(const SSL *SSL_)
 	if (_SSL != NULL)
 		[self close];
 
-	[_host release];
+	objc_release(_host);
 
 	[super dealloc];
 }
@@ -146,8 +146,14 @@ errToErrorCode(const SSL *SSL_)
 
 			OFEnsure(tmp >= 0);
 
-			[_underlyingStream writeBuffer: _buffer length: tmp];
-			[_underlyingStream flushWriteBuffer];
+			@try {
+				[_underlyingStream writeBuffer: _buffer
+							length: tmp];
+				[_underlyingStream flushWriteBuffer];
+			} @catch (OFWriteFailedException *e) {
+				if (e.errNo != EPIPE && e.errNo != ECONNRESET)
+					@throw e;
+			}
 		}
 	}
 
@@ -156,7 +162,7 @@ errToErrorCode(const SSL *SSL_)
 
 	_handshakeDone = false;
 
-	[_host release];
+	objc_release(_host);
 	_host = nil;
 
 	[super close];
@@ -264,13 +270,8 @@ errToErrorCode(const SSL *SSL_)
 
 - (bool)lowlevelHasDataInReadBuffer
 {
-#ifdef HAVE_SSL_HAS_PENDING
-	return (_underlyingStream.hasDataInReadBuffer ||
-	    SSL_has_pending(_SSL) || BIO_ctrl_pending(_readBIO) > 0);
-#else
 	return (_underlyingStream.hasDataInReadBuffer ||
 	    SSL_pending(_SSL) > 0 || BIO_ctrl_pending(_readBIO) > 0);
-#endif
 }
 
 - (void)of_asyncPerformHandshakeWithHost: (OFString *)host
@@ -375,8 +376,14 @@ errToErrorCode(const SSL *SSL_)
 
 		OFEnsure(tmp >= 0);
 
-		[_underlyingStream writeBuffer: _buffer length: tmp];
-		[_underlyingStream flushWriteBuffer];
+		@try {
+			[_underlyingStream writeBuffer: _buffer
+						length: tmp];
+			[_underlyingStream flushWriteBuffer];
+		} @catch (OFWriteFailedException *e) {
+			exception = e;
+			goto inform_delegate;
+		}
 	}
 
 	if (status == 1)
@@ -389,7 +396,7 @@ errToErrorCode(const SSL *SSL_)
 				    asyncReadIntoBuffer: _buffer
 						 length: bufferSize
 					    runLoopMode: runLoopMode];
-				[_delegate retain];
+				objc_retain(_delegate);
 				objc_autoreleasePoolPop(pool);
 				return;
 			}
@@ -402,7 +409,7 @@ errToErrorCode(const SSL *SSL_)
 		case SSL_ERROR_WANT_WRITE:
 			[_underlyingStream asyncWriteData: [OFData data]
 					      runLoopMode: runLoopMode];
-			[_delegate retain];
+			objc_retain(_delegate);
 			objc_autoreleasePoolPop(pool);
 			return;
 		case SSL_ERROR_SSL:
@@ -420,6 +427,7 @@ errToErrorCode(const SSL *SSL_)
 		}
 	}
 
+inform_delegate:
 	if (server) {
 		if ([_delegate respondsToSelector: @selector(
 		    streamDidPerformServerHandshake:exception:)])
@@ -473,8 +481,14 @@ errToErrorCode(const SSL *SSL_)
 
 			OFEnsure(tmp >= 0);
 
-			[_underlyingStream writeBuffer: _buffer length: tmp];
-			[_underlyingStream flushWriteBuffer];
+			@try {
+				[_underlyingStream writeBuffer: _buffer
+							length: tmp];
+				[_underlyingStream flushWriteBuffer];
+			} @catch (OFWriteFailedException *e) {
+				exception = e;
+				goto inform_delegate;
+			}
 		}
 
 		if (status == 1)
@@ -512,6 +526,7 @@ errToErrorCode(const SSL *SSL_)
 		}
 	}
 
+inform_delegate:
 	if (_server) {
 		if ([_delegate respondsToSelector: @selector(
 		    streamDidPerformServerHandshake:exception:)])
@@ -525,7 +540,7 @@ errToErrorCode(const SSL *SSL_)
 						    exception: exception];
 	}
 
-	[_delegate release];
+	objc_release(_delegate);
 
 	return false;
 }
@@ -546,8 +561,14 @@ errToErrorCode(const SSL *SSL_)
 
 			OFEnsure(tmp >= 0);
 
-			[_underlyingStream writeBuffer: _buffer length: tmp];
-			[_underlyingStream flushWriteBuffer];
+			@try {
+				[_underlyingStream writeBuffer: _buffer
+							length: tmp];
+				[_underlyingStream flushWriteBuffer];
+			} @catch (OFWriteFailedException *e) {
+				exception = e;
+				goto inform_delegate;
+			}
 		}
 
 		ERR_clear_error();
@@ -558,8 +579,14 @@ errToErrorCode(const SSL *SSL_)
 
 			OFEnsure(tmp >= 0);
 
-			[_underlyingStream writeBuffer: _buffer length: tmp];
-			[_underlyingStream flushWriteBuffer];
+			@try {
+				[_underlyingStream writeBuffer: _buffer
+							length: tmp];
+				[_underlyingStream flushWriteBuffer];
+			} @catch (OFWriteFailedException *e) {
+				exception = e;
+				goto inform_delegate;
+			}
 		}
 
 		if (status == 1)
@@ -592,6 +619,7 @@ errToErrorCode(const SSL *SSL_)
 		}
 	}
 
+inform_delegate:
 	if (_server) {
 		if ([_delegate respondsToSelector: @selector(
 		    streamDidPerformServerHandshake:exception:)])
@@ -605,7 +633,7 @@ errToErrorCode(const SSL *SSL_)
 						    exception: exception];
 	}
 
-	[_delegate release];
+	objc_release(_delegate);
 
 	return nil;
 }
