@@ -72,7 +72,7 @@
 
 - (void)dealloc
 {
-	[_sockServer release];
+	objc_release(_sockServer);
 
 	[super dealloc];
 }
@@ -129,7 +129,7 @@
 - (void)testAsyncSPXSocket
 {
 	SPXSocketDelegate *delegate =
-	    [[[SPXSocketDelegate alloc] init] autorelease];
+	    objc_autorelease([[SPXSocketDelegate alloc] init]);
 	uint32_t network;
 	unsigned char node[IPX_NODE_LEN];
 	uint16_t port;
@@ -207,7 +207,7 @@
   didAcceptSocket: (OFSequencedPacketSocket *)accepted
 	exception: (id)exception
 {
-	OFEnsure(!_accepted);
+	OTAssertFalse(_accepted);
 
 	_accepted = (sock == _expectedServerSocket && accepted != nil &&
 	    exception == nil);
@@ -224,7 +224,7 @@
 		 port: (uint16_t)port
 	    exception: (id)exception
 {
-	OFEnsure(!_connected);
+	OTAssertFalse(_connected);
 
 	_connected = (sock == _expectedClientSocket &&
 	    network == _expectedNetwork &&
