@@ -73,7 +73,7 @@
 
 - (void)dealloc
 {
-	[_sockServer release];
+	objc_release(_sockServer);
 
 	[super dealloc];
 }
@@ -132,7 +132,7 @@
 - (void)testAsyncSPXStreamSocket
 {
 	SPXStreamSocketDelegate *delegate =
-	    [[[SPXStreamSocketDelegate alloc] init] autorelease];
+	    objc_autorelease([[SPXStreamSocketDelegate alloc] init]);
 	uint32_t network;
 	unsigned char node[IPX_NODE_LEN];
 	uint16_t port;
@@ -210,7 +210,7 @@
   didAcceptSocket: (OFStreamSocket *)accepted
 	exception: (id)exception
 {
-	OFEnsure(!_accepted);
+	OTAssertFalse(_accepted);
 
 	_accepted = (sock == _expectedServerSocket && accepted != nil &&
 	    exception == nil);
@@ -227,7 +227,7 @@
 		 port: (uint16_t)port
 	    exception: (id)exception
 {
-	OFEnsure(!_connected);
+	OTAssertFalse(_connected);
 
 	_connected = (sock == _expectedClientSocket &&
 	    network == _expectedNetwork &&
