@@ -83,7 +83,7 @@ static const char *range80ToFF =
 
 - (void)dealloc
 {
-	[_string release];
+	objc_release(_string);
 
 	[super dealloc];
 }
@@ -107,12 +107,12 @@ static const char *range80ToFF =
 
 - (void)testCopy
 {
-	OTAssertEqualObjects([[_string copy] autorelease], _string);
+	OTAssertEqualObjects(objc_autorelease([_string copy]), _string);
 }
 
 - (void)testMutableCopy
 {
-	OTAssertEqualObjects([[_string mutableCopy] autorelease], _string);
+	OTAssertEqualObjects(objc_autorelease([_string mutableCopy]), _string);
 }
 
 - (void)testCompare
@@ -1087,7 +1087,7 @@ static const char *range80ToFF =
 - (void)testStringByXMLUnescapingWithDelegate
 {
 	EntityHandler *entityHandler =
-	    [[[EntityHandler alloc] init] autorelease];
+	    objc_autorelease([[EntityHandler alloc] init]);
 
 	OTAssertEqualObjects([[self.stringClass stringWithString: @"x&foo;y"]
 	    stringByXMLUnescapingWithDelegate: entityHandler],
@@ -1294,9 +1294,29 @@ static const char *range80ToFF =
 	    @"foo/bar/baz");
 
 	OTAssertEqualObjects([self.stringClass pathWithComponents:
-	    ([OFArray arrayWithObjects: @"foo/", @"bar", @"", @"baz", @"/",
+	    ([OFArray arrayWithObjects: @"foo", @"/", @"bar", @"", @"baz", @"/",
 	    nil])], @"foo//bar/baz//");
 
+	OTAssertEqualObjects([self.stringClass pathWithComponents:
+	    ([OFArray arrayWithObjects: @"foo//", @"bar", @"", @"baz", @"/",
+	    nil])], @"foo//bar/baz//");
+
+	OTAssertEqualObjects([self.stringClass pathWithComponents:
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"foo", @"", @"bar",
+	    @"/", nil])], @"dev:/foo/bar//");
+
+	OTAssertEqualObjects([self.stringClass pathWithComponents:
+	    ([OFArray arrayWithObjects: @"dev:/", @"foo", @"", @"bar", @"/",
+	    nil])], @"dev:/foo/bar//");
+
+	OTAssertEqualObjects([self.stringClass pathWithComponents:
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"foo", @"//", @"bar//",
+	    nil])], @"dev:/foo///bar//");
+
+	OTAssertEqualObjects([self.stringClass pathWithComponents:
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"/", @"foo", @"/", @"/",
+	    @"bar", nil])], @"dev://foo///bar");
+
 	OTAssertEqualObjects([self.stringClass pathWithComponents:
 	    [OFArray arrayWithObject: @"foo"]], @"foo");
 # elif defined(OF_WII) || defined(OF_NINTENDO_DS) || \
@@ -1377,28 +1397,35 @@ static const char *range80ToFF =
 	    pathComponents], [OFArray array]);
 # elif defined(OF_AMIGAOS)
 	OTAssertEqualObjects([[self.stringClass stringWithString:
-	    @"dh0:tmp"] pathComponents],
-	    ([OFArray arrayWithObjects: @"dh0:", @"tmp", nil]));
-
-	OTAssertEqualObjects([[self.stringClass stringWithString:
-	    @"dh0:tmp/"] pathComponents],
-	    ([OFArray arrayWithObjects: @"dh0:", @"tmp", nil]));
-
-	OTAssertEqualObjects([[self.stringClass stringWithString:
-	    @"dh0:/"] pathComponents],
-	    ([OFArray arrayWithObjects: @"dh0:", @"/", nil]));
-
-	OTAssertEqualObjects([[self.stringClass stringWithString:
-	    @"foo/bar"] pathComponents],
-	    ([OFArray arrayWithObjects: @"foo", @"bar", nil]));
+	    @"dh0:foo/bar/baz"] pathComponents],
+	    ([OFArray arrayWithObjects: @"dh0:", @"foo", @"bar", @"baz", nil]));
 
 	OTAssertEqualObjects([[self.stringClass stringWithString:
 	    @"foo/bar/baz/"] pathComponents],
 	    ([OFArray arrayWithObjects: @"foo", @"bar", @"baz", nil]));
 
 	OTAssertEqualObjects([[self.stringClass stringWithString:
-	    @"foo//"] pathComponents],
-	    ([OFArray arrayWithObjects: @"foo", @"/", nil]));
+	    @"foo//bar/baz//"] pathComponents],
+	    ([OFArray arrayWithObjects: @"foo", @"/", @"bar", @"baz", @"/",
+	    nil]));
+
+	OTAssertEqualObjects([[self.stringClass stringWithString:
+	    @"dev:/foo/bar//"] pathComponents],
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"foo", @"bar", @"/",
+	    nil]));
+
+	OTAssertEqualObjects([[self.stringClass stringWithString:
+	    @"dev:/foo///bar//"] pathComponents],
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"foo", @"/", @"/",
+	    @"bar", @"/", nil]));
+
+	OTAssertEqualObjects([[self.stringClass stringWithString:
+	    @"dev://foo///bar"] pathComponents],
+	    ([OFArray arrayWithObjects: @"dev:", @"/", @"/", @"foo", @"/", @"/",
+	    @"bar", nil]));
+
+	OTAssertEqualObjects([[self.stringClass stringWithString: @"foo/"]
+	    pathComponents], [OFArray arrayWithObject: @"foo"]);
 
 	OTAssertEqualObjects([[self.stringClass stringWithString: @""]
 	    pathComponents], [OFArray array]);
@@ -1712,7 +1739,7 @@ static const char *range80ToFF =
 	@try {
 		_string = [[OFMutableString alloc] init];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1726,7 +1753,7 @@ static const char *range80ToFF =
 	@try {
 		_string = [string mutableCopy];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1744,7 +1771,7 @@ static const char *range80ToFF =
 							  encoding: encoding
 							    length: length];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1763,7 +1790,7 @@ static const char *range80ToFF =
 				 length: length
 			      byteOrder: byteOrder];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1782,7 +1809,7 @@ static const char *range80ToFF =
 				 length: length
 			      byteOrder: byteOrder];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1798,7 +1825,7 @@ static const char *range80ToFF =
 		_string = [[OFMutableString alloc] initWithFormat: format
 							arguments: arguments];
 	} @catch (id e) {
-		[self release];
+		objc_release(self);
 		@throw e;
 	}
 
@@ -1807,7 +1834,7 @@ static const char *range80ToFF =
 
 - (void)dealloc
 {
-	[_string release];
+	objc_release(_string);
 
 	[super dealloc];
 }
